# Configure document

## Complete configuration

```yml
# serverless.yml

restApi:
  component: '@serverless/tencent-apigateway'
  inputs:
    serviceId: service-8dsikiq6
    region: ap-shanghai
    protocols:
      - http
      - https
    serviceName: serverless
    description: the serverless service
    environment: release
    endpoints:
      - path: /
        method: GET
        protocol: WEBSOCKET
        function:
          # for websocket type, transportFunctionName is required
          transportFunctionName: myFunction
          registerFunctionName: myFunction
          cleanupFunctionName: myFunction
      - path: /users
        method: POST
        function:
          functionName: myFunction
      - path: /test/{abc}/{cde}
        apiId: api-id
        method: GET
        description: Serverless REST API
        enableCORS: TRUE
        responseType: HTML
        serviceTimeout: 10
        param:
          - name: abc
            position: PATH
            required: 'TRUE'
            type: string
            defaultValue: abc
            desc: mytest
          - name: cde
            position: PATH
            required: 'TRUE'
            type: string
            defaultValue: abc
            desc: mytest
        function:
          isIntegratedResponse: TRUE
          functionQualifier: $LATEST
          functionName: myFunction
        usagePlan:
          usagePlanId: 1111
          usagePlanName: slscmp
          usagePlanDesc: sls create
          maxRequestNum: 1000
        auth:
          serviceTimeout: 15
          secretName: secret
          secretIds:
            - AKIDNSdvdFcJ8GJ9th6qeZH0ll8r7dE6HHaSuchJ
```

## Configuration description

Main param description

| Param                                     | Required/Optional | Default | Description                                                                                              |
| ----------------------------------------- | :---------------: | :-----: | :------------------------------------------------------------------------------------------------------- |
| serviceId                                 |     Optional      |         | The globally unique ID of the service generated by the system.                                           |
| region                                    |     Required      |         |                                                                                                          |
| protocols                                 |     Required      |         | Frontend request type of the service, such as HTTP, HTTPS, HTTP and HTTPS. （http / https）              |
| serviceName                               |     Optional      |         | User-defined service name. The system automatically generates a unique name if nothing is passed.        |
| description                               |     Optional      |         | User-defined service description.                                                                        |
| environment                               |     Required      |         | The name of the environment to be published. Three environments are supported: test, prepub and release. |
| [endpoints](#endpoints-param-description) |     Required      |         | API                                                                                                      |

### endpoints param description

| Param          | Required/Optional | Default | Description                                                                                         |
| -------------- | :---------------: | :-----: | :-------------------------------------------------------------------------------------------------- |
| apiId          |     Optional      |         | Unique ID of the API.                                                                               |
| protocol       |     Optional      |         | Specify frontend api type, default `HTTP`, if you want to create websocket api, set to `WEBSOCKET`. |
| path           |     Required      |         | Path.                                                                                               |
| method         |     Required      |         | Request method.                                                                                     |
| description    |     Optional      |         | Description                                                                                         |
| enableCORS     |     Optional      |         | Indicates whether to enable cross-origin access. TRUE: enable; FALSE: not enable. Default is FALSE. |
| function       |     Required      |         | Serverless Cloud Function                                                                           |
| usagePlan      |     Optional      |         |                                                                                                     |
| auth           |     Optional      |         |                                                                                                     |
| serviceTimeout |     Optional      |         | Service Timeout                                                                                     |
| responseType   |     Optional      |         | ResponseType: HTML、JSON、TEST、BINARY、XML                                                         |
| param          |     Optional      |         | Param                                                                                               |

- function param description

| Param                | Description                                                                                                                 |
| -------------------- | :-------------------------------------------------------------------------------------------------------------------------- |
| isIntegratedResponse | Response integration                                                                                                        |
| functionQualifier    | Functioin qualifier                                                                                                         |
| functionName         | Name of the SCF function of the backend service corresponding to the API. This parameter is required if serviceType is SCF. |

- usagePlan param description

| Param         | Description                                                                                                   |
| ------------- | :------------------------------------------------------------------------------------------------------------ |
| usagePlanId   | User-defined usage plan id                                                                                    |
| usagePlanName | User-defined usage plan name                                                                                  |
| usagePlanDesc | User-defined usage plan description                                                                           |
| maxRequestNum | Total number of requests allowed. If this is left empty, -1 will be used by default, indicating it’s disabled |

- auth param description

| Param          | Description                                                                                                            |
| -------------- | :--------------------------------------------------------------------------------------------------------------------- |
| serviceTimeout | Service timeout                                                                                                        |
| secretName     | User-defined secret key name.                                                                                          |
| secretIds      | User-defined secretID, which is required when type is manual. It can contain 5 to 50 letters, digits, and underscores. |

- param param description

| Param        | Description                                                                                                                        |
| ------------ | :--------------------------------------------------------------------------------------------------------------------------------- |
| name         | Name of the parameter in the request for calling the API from frontend.                                                            |
| position     | Position of the parameter in the request for calling the API from frontend. Only PATH, QUERY and HEADER are supported.             |
| type         | Type of the parameter in the request for calling the API from frontend, such as String and int.                                    |
| defaultValue | Default value of the parameter in the request for calling the API from frontend.                                                   |
| required     | Indicates whether the parameter in the request for calling the API from frontend is required. 'TRUE': required; 'FALSE': optional. |
| desc         | Description of the parameter in the request for calling the API from frontend.                                                     |
